SSHChannel class

Constructors

SSHChannel(SSHChannelController _controller)

Properties

channelId → int
The channel id on the local side.
no setter
done → Future<void>
no setter
hashCode → int
The hash code for this object.
no setterinherited
maximumPacketSize → int
The maximum packet size that the remote side can receive.
no setter
remoteChannelId → int
The channel id on the remote side.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sink → StreamSink<SSHChannelData>
A StreamSink that sends data to the remote side. Chucks must be equal to or less than maximumPacketSize.
no setter
stream → Stream<SSHChannelData>
A Stream of data received from the remote side.
no setter

Methods

addData(Uint8List data, {int? type}) → void
Send data to the remote side.
close() → Future<void>
Closes our side of the channel. Returns a Future that completes when both sides of the channel are closed.
destroy() → void
Destroys the channel in both directions. After calling this method, no more data can be sent or received.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendExec(String command) → Future<bool>
sendShell() → Future<bool>
sendSignal(String signal) → void
sendTerminalWindowChange({required int width, required int height, int pixelWidth = 0, int pixelHeight = 0}) → void
setRequestHandler(SSHChannelRequestHandler handler) → void
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited