SSHChannelDataSplitter class

Inheritance

Constructors

SSHChannelDataSplitter(int maxSize)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxSize → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bind(Stream<SSHChannelData> stream) → Stream<SSHChannelData>
Transforms the provided stream.
override
cast<RS, RT>() → StreamTransformer<RS, RT>
Provides a StreamTransformer<RS, RT> view of this stream transformer.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited