AsyncQueue<T> class

A queue that consumers can wait asynchronously for items to be added.

Constructors

AsyncQueue()

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasWaiters → bool
Return true if the queue has consumers waiting for items.
no setter
length → int
The length of the queue.
no setter
next → FutureOr<T>
Returns a Future that completes when an item is added to the queue.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(T value) → void
Adds an item to the queue.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited