ChunkBuffer class

A buffer that can queue chunks of data and consume parts or all of them as needed. Primarily used for reading data from a socket.

Constructors

ChunkBuffer()

Properties

byteData → ByteData
no setter
data → Uint8List
no setter
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
isNotEmpty → bool
no setter
length → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Uint8List data) → void
clear() → void
consume([int? length]) → Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
view(int start, int length) → Uint8List

Operators

operator ==(Object other) → bool
The equality operator.
inherited