ByteConsumer class

UncompleteDocumentation

Constructors

ByteConsumer()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
UncompleteDocumentation
no setter
isNotEmpty → bool
UncompleteDocumentation
no setter
length → int
UncompleteDocumentation
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalConsumed → int
UncompleteDocumentation
no setter

Methods

add(String data) → void
UncompleteDocumentation
consume() → int
UncompleteDocumentation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peek() → int
UncompleteDocumentation
reset() → void
Resets the consumer to its initial state.
rollback([int n = 1]) → void
Rolls back the last n call.
rollbackTo(int length) → void
Rolls back to the state when this consumer had length bytes.
toString() → String
A string representation of this object.
inherited
unrefConsumedBlocks() → void
Unreferences data blocks that have been consumed. After calling this method, the consumer will not be able to roll back to consumed blocks.

Operators

operator ==(Object other) → bool
The equality operator.
inherited